# -*- coding: utf-8 -*-

from datetime import datetime
from random import shuffle
from django.http import HttpResponse, HttpResponseRedirect
from django.contrib.auth.forms import AuthenticationForm
from django.db import models as db

